## Summary

This ReviewType contains a basic setup for literature reviews. It is a good choice to try the CoLRev system. Similar to the other packages for review types, it can be used to complete a review project and report each step for a standalone review paper.

For standalone review papers, it is recommended to use a specific review type, such as a [scoping review](colrev.scoping_review.html) or a [qualitative systematic review](colrev.qualitative_systematic_review.html).

## Characteristics

- N/A. The characteristics of literature reviews vary considerably when no review type is specified.

## Data extraction, analysis, and synthesis

- For the synthesis, the [colrev.paper_md](colrev.paper_md.html) is activated, which creates the ``data/data/paper.md`` file. This file can be used to keep notes, draft a review protocol, and to write a synthesis. Based on the ``paper.md``, the ``output/paper.docx`` is generated automatically.
- To extract structured data, or conduct other forms of analysis and synthesis, other [data packages](https://colrev-environment.github.io/colrev/manual/data/data.html) can be activated.

## Textbooks

Fink, A. (2019). Conducting research literature reviews: From the internet to paper. Sage publications. ISBN: 9781544318462.

Hart, C. (2018). Doing a literature review: Releasing the research imagination. Sage publications. ISBN: 9781526423146.
